#!/bin/sh
# Copyright (C) 2000-2016 Synology Inc. All rights reserved.

###################################
# Java7 install script file
#
# Usage:
#       $0 JRE_FILE_PATH
#
# Return Value:
#       0: Every thing is ok, done.
#       1: Script error.
#       2: Archive is not existed.
#       3: Java7 package is not installed.
#       4: Not support archive.
#       5: Free space is not enough when extract jdk.
#       6: Archive cannot be extracted properly.
#       7: Can't upgrade jdk due to dependent packages.
#       8: File format error, missing must-have files.
#
##################################

JAVA_PATH="$1"
JDK_SIZE="300000" # unit is KB (ie. 300MB)

. /var/packages/Java7/scripts/common

CheckVariable()
{
	if [ -z ${JAVA_PATH} ]; then
		exit 1
	fi
	if [ ! -f ${JAVA_PATH} ]; then
		exit 2
	fi
	if [ ! -d ${SYNOPKG_PKGDEST} ]; then
		exit 3
	fi
}

CheckArchive()
{
	tar tf ${JAVA_PATH} > /dev/null
	if [ $? != 0 ]; then
		exit 4
	fi
}

CheckFreeSpace()
{
	local VOLUME=`readlink ${SYNOPKG_PKGDEST} | cut -d/ -f2`
	local FREE_SPACE=`df | grep ${VOLUME} | awk 'NF && NF-1 && NF-2 {print $(NF-2)}'`

	# The df result on DDSM will be "", we skip space check to do tar directly.
	# If the space/quota is not enough, tar command will be failed.
	if [ "${FREE_SPACE}" -eq "${FREE_SPACE}" ] 2>/dev/null; then
		if [ "${FREE_SPACE}" -lt "${JDK_SIZE}" ]; then
			exit 5
		fi
	fi
}

CheckDepPkg()
{
	local dep_pkgs=`sh ${SYNOPKG_PKGDEST}/ui/remove.sh`
	if [ -n "$dep_pkgs" ]; then
		echo $dep_pkgs
		exit 7
	fi
}

InstallJava()
{
	CheckVariable
	CheckArchive
	CheckFreeSpace

	# if Upgrade Java, we need to check dep pkg and remove old java
	if [ -e ${SYNOPKG_PKGDEST}/${EXTRACT_FOLDER_NAME} ]; then
		CheckDepPkg
	fi

	# Get extract folder name
	JAVA_DECOMPRESS_DIRECTORY=`tar tf ${JAVA_PATH} | head -n1`

	tar xf ${JAVA_PATH} -C ${SYNOPKG_PKGDEST}
	if [ $? != 0 ]; then
		rm -rf ${SYNOPKG_PKGDEST}/${JAVA_DECOMPRESS_DIRECTORY}
		exit 6
	fi

	cd ${SYNOPKG_PKGDEST}

	# Check for must-have files
	MUST_HAVE_LIST="/bin/unpack200 /jre/lib/rt.jar /lib/tools.jar /bin/javac /jre/bin/java"

	for f in ${MUST_HAVE_LIST}
	do
		if [ ! -e ${SYNOPKG_PKGDEST}/${JAVA_DECOMPRESS_DIRECTORY}${f} ]; then
			rm -rf ${SYNOPKG_PKGDEST}/${JAVA_DECOMPRESS_DIRECTORY}
			exit 8
		fi
	done

	rm -rf ${SYNOPKG_PKGDEST}/${EXTRACT_FOLDER_NAME}
	mv ${SYNOPKG_PKGDEST}/${JAVA_DECOMPRESS_DIRECTORY} ${SYNOPKG_PKGDEST}/${EXTRACT_FOLDER_NAME}
}

InstallJava
#AddEnvVar ${USR_PROFILE}
#AddEnvVar ${SYS_PROFILE}
exit 0
