// Copyright (C) 2000-2014 Synology Inc. All rights reserved.

Ext.ns('SYNO.SDS.JAVA7');

Ext.define('SYNO.SDS.JAVA7.InstallerPanel', {
	extend: 'Ext.form.FormPanel',
	getStepDescription: function() {
		var ret = "<ol>";
		var step1 = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_step1");
		var step2 = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_step2");
		var step3 = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_step3");
		var step4 = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_step4");

		step1 = String.format(step1, SYNO.SDS.JAVA7.JAVA_DOWNLOAD_SITE_URL, 
			SYNO.SDS.JAVA7.JAVA_DOWNLOAD_SITE_TITLE);
		step2 = String.format(step2, SYNO.SDS.JAVA7.JAVA_DOWNLOAD_LINK_VERSION_STRING, 
			SYNO.SDS.JAVA7.JAVA_DOWNLOAD_MAJOR_VERSION,	
			SYNO.SDS.JAVA7.JAVA_DOWNLOAD_MINOR_VERSION);
		step3 = String.format(step3, SYNO.SDS.JAVA7.JAVA_DOWNLOAD_PRODUCT,
			SYNO.SDS.JAVA7.JAVA_DOWNLOAD_FILENAME,
			SYNO.SDS.JAVA7.JAVA_DOWNLOAD_MINOR_VERSION);
		
		ret += "<li>" + step1 + "</li>";
		ret += "<li>" + step2 + "</li>";
		ret += "<li>" + step3 + "</li>";
		ret += "<li>" + step4 + "</li>";
		ret += "</ol>";

		return ret;
	},
	constructor: function(override, isUpgrade) {
		var step_introduction;
		if (isUpgrade) {
			step_introduction = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "upgrade_step_introduction");
		} else {
			step_introduction = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_step_introduction");
		}
		var config = Ext.apply({
			items: [{
				xtype: 'syno_displayfield',
				value: step_introduction
			}, {
				xtype: 'syno_displayfield',
				htmlEncode: false,
				value: this.getStepDescription(),
				cls: "java_manager_installer_list",
				indent: 2
			}, {
				itemId: 'file',
				synotype: 'indent_no_label',
				xtype: 'syno_filebutton',
				name: 'upload_file',
				indent: 2
			}],
			fileUpload: true,
			url: SYNO.SDS.JAVA7.CGI_INSTALL,
			itemId: 'form',
			headline: _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_java"),
			border: false,
			description: ""
		}, override);

		this.callParent([config]);

		this.mon(this.getForm(), 'actioncomplete', this.actionComplete, this);
		this.mon(this.getForm(), 'actionfailed', this.actionFailed, this);
	},
	upload: function() {
		// File is not selected
		if (!this.getComponent('file').getValue()) {
			this.owner.setStatusError({text: _TT("SYNO.SDS.JAVA7.Instance", "wizard", "please_select_file"), clear: true});
			return;
		}

		this.owner.setStatusBusy();
		this.getForm().doAction('apply');
		return;
	},
	actionComplete: function(obj, action) {
		// Set last step is install step
		this.owner.clearStatusBusy();
		this.owner.getMsgBox().alert(_TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_success"),
			_TT("SYNO.SDS.JAVA7.Instance", "wizard", "success_message"), function() {
				this.owner.close();
			}, this);
	},
	actionFailed: function(obj, action) {
		this.owner.clearStatusBusy();
		this.owner.getMsgBox().alert(_TT("SYNO.SDS.JAVA7.Instance", "wizard", "error"),
			this.getErrorMessage(action.result));
	},
	getErrorMessage: function(result) {
		switch(result.error_message) {
			case "file_format_error":
				return _TT("SYNO.SDS.JAVA7.Instance", "wizard", "error_file_format");
			case "not_enough_disk_space":
				return _TT("SYNO.SDS.JAVA7.Instance", "wizard", "error_not_enough_disk");
			case "not_support_archive":
				return _TT("SYNO.SDS.JAVA7.Instance", "wizard", "error_not_archive");
			case "archive_extract_fail":
				return _TT("SYNO.SDS.JAVA7.Instance", "wizard", "archive_extract_fail");
			case "dep":
				return _TT("SYNO.SDS.JAVA7.Instance", "main", "upgrade_dep_error") + "<br />" + result.list.split(" ").join(", ");
			case "script":
			case "abnormal":
				return _T("error", "error_unknown");
			default:
				return _T("error", "error_unknown");
		}
	}
});

Ext.define('SYNO.SDS.JAVA7.Installer', {
	extend: 'SYNO.SDS.ModalWindow',
	constructor: function(config, isUpgrade) {
		this.module = config.module;
		this.owner = config.owner;
		this.panel = new SYNO.SDS.JAVA7.InstallerPanel({owner: this}, isUpgrade);
		var title;
		if (isUpgrade) {
			title = _TT("SYNO.SDS.JAVA7.Instance", "main", "upgrade_java");
		} else {
			title = _TT("SYNO.SDS.JAVA7.Instance", "wizard", "install_java");
		}

		config = Ext.apply({
			title: title,
			resizable: false,
			width: 550,
			height: 370,
			dsmStyle: 'v5',
			buttons: [{
				xtype: 'syno_button',
				disabled: _S('demo_mode'),
				tooltip: _S('demo_mode') ? _JSLIBSTR('uicommon', 'error_demo') : '',
				text: _T('common', 'apply'),
				scope: this,
				handler: this.upload
			}, {
				xtype: 'syno_button',
				text: _T('common', 'cancel'),
				scope: this,
				handler: this.close
			}],
			items: [this.panel]
		}, config);
		this.callParent([config]);
	},
	upload: function() {
		this.panel.upload();
	}
});
